Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(976)

Unified Diff: ui/views/window/dialog_client_view.h

Issue 2737913002: Fix missing buttons on the Edit Bookmark dialog. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/views/window/dialog_client_view.cc » ('j') | ui/views/window/dialog_client_view.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/window/dialog_client_view.h
diff --git a/ui/views/window/dialog_client_view.h b/ui/views/window/dialog_client_view.h
index ff184b877617cc44b1805a81a96ce10711dfc6c4..69b03e2c36d56e9f5802ba70ba3e017dba313514 100644
--- a/ui/views/window/dialog_client_view.h
+++ b/ui/views/window/dialog_client_view.h
@@ -127,8 +127,9 @@ class VIEWS_EXPORT DialogClientView : public ClientView,
// twice, which can have bad consequences.
bool delegate_allowed_close_ = false;
- // When true, prevents ViewHierarchyChanged() from clearing out data members.
- bool preserve_button_row_data_members_ = false;
+ // When true, prevents ViewHierarchyChanged() from clearing out data members
+ // and spurious triggers to Layout() from extra views.
Peter Kasting 2017/03/08 11:33:17 This comment is now overly specific, since the mem
tapted 2017/03/08 12:19:03 Done.
+ bool adding_or_removing_views_ = false;
DISALLOW_COPY_AND_ASSIGN(DialogClientView);
};
« no previous file with comments | « no previous file | ui/views/window/dialog_client_view.cc » ('j') | ui/views/window/dialog_client_view.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698